/**
 * A brief explanation for "project.json":
 * Here is the content of project.json file, this is the global configuration for your game, you can modify it to customize some behavior.
 * The detail of each field is under it.
 {
    "project_type": "javascript",
    // "project_type" indicate the program language of your project, you can ignore this field

    "debugMode"     : 1,
    // "debugMode" possible values :
    //      0 - No message will be printed.
    //      1 - cc.error, cc.assert, cc.warn, cc.log will print in console.
    //      2 - cc.error, cc.assert, cc.warn will print in console.
    //      3 - cc.error, cc.assert will print in console.
    //      4 - cc.error, cc.assert, cc.warn, cc.log will print on canvas, available only on web.
    //      5 - cc.error, cc.assert, cc.warn will print on canvas, available only on web.
    //      6 - cc.error, cc.assert will print on canvas, available only on web.

    "showFPS"       : true,
    // Left bottom corner fps information will show when "showFPS" equals true, otherwise it will be hide.

    "frameRate"     : 60,
    // "frameRate" set the wanted frame rate for your game, but the real fps depends on your game implementation and the running environment.

    "noCache"       : false,
    // "noCache" set whether your resources will be loaded with a timestamp suffix in the url.
    // In this way, your resources will be force updated even if the browser holds a cache of it.
    // It's very useful for mobile browser debuging.

    "id"            : "gameCanvas",
    // "gameCanvas" sets the id of your canvas element on the web page, it's useful only on web.

    "renderMode"    : 0,
    // "renderMode" sets the renderer type, only useful on web :
    //      0 - Automatically chosen by engine
    //      1 - Forced to use canvas renderer
    //      2 - Forced to use WebGL renderer, but this will be ignored on mobile browsers

    "engineDir"     : "frameworks/cocos2d-html5/",
    // In debug mode, if you use the whole engine to develop your game, you should specify its relative path with "engineDir",
    // but if you are using a single engine file, you can ignore it.

    "modules"       : ["cocos2d"],
    // "modules" defines which modules you will need in your game, it's useful only on web,
    // using this can greatly reduce your game's resource size, and the cocos console tool can package your game with only the modules you set.
    // For details about modules definitions, you can refer to "../../frameworks/cocos2d-html5/modulesConfig.json".

    "jsList"        : [
    ]
    // "jsList" sets the list of js files in your game.
 }
 *
 */

var WINW=640;
var WINH=1136;

cc.game.onStart = function(){
    if(!cc.sys.isNative && document.getElementById("cocosLoading")) //If referenced loading.js, please remove it
        document.body.removeChild(document.getElementById("cocosLoading"));

    // Pass true to enable retina display, on Android disabled by default to improve performance
    cc.view.enableRetina(cc.sys.os === cc.sys.OS_IOS ? true : false);

    // Adjust viewport meta
    cc.view.adjustViewPort(true);

    // Uncomment the following line to set a fixed orientation for your game
    // cc.view.setOrientation(cc.ORIENTATION_PORTRAIT);

    // Setup the resolution policy and design resolution size
    if (cc.sys.isMobile) cc.view.setDesignResolutionSize(WINW, WINH, cc.ResolutionPolicy.FIXED_WIDTH);
    else{
        cc.view.setDesignResolutionSize(WINW, WINH, cc.ResolutionPolicy.SHOW_ALL);
        WINSIZE=cc.size(WINW,WINH);
    }

    //  支付回调
    wb.PayManager.setOnPayFinishCallback(function(payParams){
        var result=payParams.getPayResult();
        var payid=payParams.getPayId();
        cc.log("pay Resule:"+result+"-----"+"payId"+payid);
        //支付统计
        if(result==0)
        {
            switch(payid)
            {
                case 1:ELSGameTool.getInstance().clickUm("hj_pay","type_6");break;
                case 2:ELSGameTool.getInstance().clickUm("hj_pay","type_12");break;
                case 3:ELSGameTool.getInstance().clickUm("hj_pay","type_18");break;
                case 4:ELSGameTool.getInstance().clickUm("hj_pay","type_19");break;
                case 6:ELSGameTool.getInstance().clickUm("hj_pay","type_limit");break;
                case 7:ELSGameTool.getInstance().clickUm("hj_pay","type_new");break;
            }
        }
        //支付成功
        if(cc.sys.platform==cc.sys.WIN32||result==0) {
            var diamondnum=ZSNUM[payid-1];
            ELSGameLogic.getInstance().useIcon(diamondnum);
            ELSGameTool.getInstance().diamondMotion(diamondnum);
            if(payid==5){
                //去广告礼包（去掉广告）
                ELSGameData.getInstance().buyGift(5,true);
                GameUserInfo.getInstance().setIsShopGiftChenged(true);
                wb.setADEnabled(false);
            }
            else if(payid==6){
                //限时礼包
                ELSGameData.getInstance().buyGift(6,true);
            }
            else if(payid==7){
                //新手礼包
                ELSGameData.getInstance().buyGift(7,true);
                GameUserInfo.getInstance().setIsShopGiftChenged(true);
            }
       }
    });

    // The game will be resized when browser size change
    cc.view.resizeWithBrowserSize(true);
    cc.director.setDisplayStats(false);
    //load resources
    cc.LoaderScene.preload(g_resources, function () {
        wb.HJCore.init();
        ELSGameLogic.getInstance().getRankData();
        ELSGameLogic.getInstance().getLastVersionDiamond();
        cc.director.runScene(new MainScene2());
    }, this);
};
cc.game.run();